[open-ils-commits] r19045 - in branches/rel_1_6/Open-ILS/src/sql/Pg: . upgrade (miker)
svn at svn.open-ils.org
svn at svn.open-ils.org
Wed Dec 22 20:33:04 EST 2010
Author: miker
Date: 2010-12-22 20:33:02 -0500 (Wed, 22 Dec 2010)
New Revision: 19045
Added:
branches/rel_1_6/Open-ILS/src/sql/Pg/upgrade/0473.schema.vandelay-replace_field.sql
Modified:
branches/rel_1_6/Open-ILS/src/sql/Pg/012.schema.vandelay.sql
Log:
allow vandelay.replace_field() to handle a complex field spec by splitting and looping
Modified: branches/rel_1_6/Open-ILS/src/sql/Pg/012.schema.vandelay.sql
===================================================================
--- branches/rel_1_6/Open-ILS/src/sql/Pg/upgrade/0473.schema.vandelay-replace_field.sql (rev 0)
+++ branches/rel_1_6/Open-ILS/src/sql/Pg/upgrade/0473.schema.vandelay-replace_field.sql 2010-12-23 01:33:02 UTC (rev 19045)
@@ -0,0 +1,35 @@
+
+BEGIN;
+
+INSERT INTO config.upgrade_log (version) VALUES ('0473'); -- miker
+
+CREATE OR REPLACE FUNCTION vandelay.replace_field ( target_xml TEXT, source_xml TEXT, field TEXT ) RETURNS TEXT AS $_$
+DECLARE
+ xml_output TEXT;
+ parsed_target TEXT;
+ curr_field TEXT;
+BEGIN
+
+ parsed_target := vandelay.strip_field( target_xml, ''); -- this dance normalizes the format of the xml for the IF below
+
+ FOR curr_field IN SELECT UNNEST( STRING_TO_ARRAY(field, ',') ) LOOP -- naive split, but it's the same we use in the perl
+
+ xml_output := vandelay.strip_field( parsed_target, curr_field);
+
+ IF xml_output <> parsed_target AND curr_field ~ E'~' THEN
+ -- we removed something, and there was a regexp restriction in the curr_field definition, so proceed
+ xml_output := vandelay.add_field( xml_output, source_xml, curr_field, 1 );
+ ELSIF curr_field !~ E'~' THEN
+ -- No regexp restriction, add the curr_field
+ xml_output := vandelay.add_field( xml_output, source_xml, curr_field, 0 );
+ END IF;
+
+ parsed_target := xml_output; -- in prep for any following loop iterations
+
+ END LOOP;
+
+ RETURN xml_output;
+END;
+$_$ LANGUAGE PLPGSQL;
+
+COMMIT;
More information about the open-ils-commits
mailing list
--- branches/rel_1_6/Open-ILS/src/sql/Pg/012.schema.vandelay.sql 2010-12-23 01:28:33 UTC (rev 19044)
+++ branches/rel_1_6/Open-ILS/src/sql/Pg/012.schema.vandelay.sql 2010-12-23 01:33:02 UTC (rev 19045)
@@ -269,18 +269,27 @@
DECLARE
xml_output TEXT;
parsed_target TEXT;
+ curr_field TEXT;
BEGIN
- parsed_target := vandelay.strip_field( target_xml, ''); -- this dance normalized the format of the xml for the IF below
- xml_output := vandelay.strip_field( parsed_target, field);
- IF xml_output <> parsed_target AND field ~ E'~' THEN
- -- we removed something, and there was a regexp restriction in the field definition, so proceed
- xml_output := vandelay.add_field( xml_output, source_xml, field, 1 );
- ELSIF field !~ E'~' THEN
- -- No regexp restriction, add the field
- xml_output := vandelay.add_field( xml_output, source_xml, field, 0 );
- END IF;
+ parsed_target := vandelay.strip_field( target_xml, ''); -- this dance normalizes the format of the xml for the IF below
+ FOR curr_field IN SELECT UNNEST( STRING_TO_ARRAY(field, ',') ) LOOP -- naive split, but it's the same we use in the perl
+
+ xml_output := vandelay.strip_field( parsed_target, curr_field);
+
+ IF xml_output <> parsed_target AND curr_field ~ E'~' THEN
+ -- we removed something, and there was a regexp restriction in the curr_field definition, so proceed
+ xml_output := vandelay.add_field( xml_output, source_xml, curr_field, 1 );
+ ELSIF curr_field !~ E'~' THEN
+ -- No regexp restriction, add the curr_field
+ xml_output := vandelay.add_field( xml_output, source_xml, curr_field, 0 );
+ END IF;
+
+ parsed_target := xml_output; -- in prep for any following loop iterations
+
+ END LOOP;
+
RETURN xml_output;
END;
$_$ LANGUAGE PLPGSQL;
Copied: branches/rel_1_6/Open-ILS/src/sql/Pg/upgrade/0473.schema.vandelay-replace_field.sql (from rev 19043, trunk/Open-ILS/src/sql/Pg/upgrade/0473.schema.vandelay-replace_field.sql)
===================================================================